Index: runtime/observatory/lib/src/models/objects/isolate.dart |
diff --git a/runtime/observatory/lib/src/models/objects/isolate.dart b/runtime/observatory/lib/src/models/objects/isolate.dart |
index 8c1e3672390d3024b7d34140b5f67911f6464c20..f1d1147f8c5917f6d1433ed6555605014d6731ad 100644 |
--- a/runtime/observatory/lib/src/models/objects/isolate.dart |
+++ b/runtime/observatory/lib/src/models/objects/isolate.dart |
@@ -54,10 +54,10 @@ abstract class Isolate extends IsolateRef { |
/// The list of threads associated with this isolate. |
Iterable<Thread> get threads; |
/// The maximum amount of memory in bytes allocated by the isolate in all |
/// threads at a given time. Calculated using the high watermarks of each |
/// thread alive when a thread is unscheduled. |
- int get memoryHighWatermark; |
+ int get zoneHighWatermark; |
/// The number of zone handles currently held by this isolate. |
int get numZoneHandles; |
@@ -54,10 +54,10 @@ abstract class Isolate extends IsolateRef { |
/// The list of threads associated with this isolate. |
Iterable<Thread> get threads; |
- /// The maximum amount of memory in bytes allocated by the isolate in all |
- /// threads at a given time. Calculated using the high watermarks of each |
+ /// The maximum amount of zone memory in bytes allocated by the isolate in |
+ /// all threads at a given time. Calculated using the high watermarks of each |
/// thread alive when a thread is unscheduled. |